#!/bin/bash 

# This script constructs (via aunfold) an approximated unfolding for the example of red-black trees. 
# Input: red-black.xml (in GTXL standard for graph transformation systems).
# Output: out.xml (in GXL standard for the Petri graph obtained by the construction of the approximated unfolding).

# Script also performs a visualisation of the example: 
# pg2neato extracts the Petri net and hypergraph components of the Petri graph. 
# Input: out.xml
# Output: neatoInput.petriNet / neatoInput.hypergraph files
# By the means of the dot/neato programs the following files are constructed: 
# out.pn.ps as a visualisation of the Petri net 
# out.hg.ps as a visualisation of the hypergraph. 

if [ -f out.xml ]
then 
rm out.xml
fi 

if [ -f ../../example/red-black.xml ]
then 

#approximated unfolding constructed
./../../bin/aunfold ../../example/red-black.xml out.xml   

if [ -f out.xml ]
then 


# ------ Visualisation ------
#extract the Petri net and hypergraph components and transform them to neato/dot input format
./../../bin/pg2neato -pn out.xml > neatoInput.petriNet
./../../bin/pg2neato -hg out.xml > neatoInput.hypergraph

#See Graphviz documentation at http://www.research.att.com/sw/tools/graphviz for additional details on dot and neato.
if [ -f neatoInput.petriNet ]
then
dot -Tps -Goverlap=false neatoInput.petriNet > out.pn.ps                
else echo "Missing neatoInput.petriNet file"
fi 

if [ -f neatoInput.hypergraph ]
then
neato -Tps -Goverlap=false neatoInput.hypergraph > out.hg.ps
else echo "Missing neatoInput.hypergraph file"
fi 
# ---------------------------

else  "Error in aunfold: no out.xml constructed!"
fi # out

else echo "Missing red-black.xml file!"
fi # red-black
